@@ -6,42 +6,79 @@ use strict;
 use warnings;
 use Carp;
 
-use version; our $VERSION = qv('v0.0.4');
+use version; our $VERSION = qv('v0.0.5');
 
 use Exporter qw( import );
 
 our @EXPORT_OK =
     qw{
-        load_icao_history
-        validate_icao_history_set
-        validate_icao_history_point
-        validate_icao
-        validate_date
-        validate_wind_direction
-        validate_wind_speed_knots
-        validate_gust_speed_knots
-        validate_visibility_miles
-        validate_temperature_c
-        validate_dewpoint_c
-        validate_pressure_hpa
-        validate_relative_humidity
+        &convert_from_fahrenheit_to_celsius
+        &convert_from_inches_of_mercury_to_hectopascals
+        &convert_from_miles_per_hour_to_knots
+
+        &clean_icao_history_set
+        &clean_icao_history_point
+        &clean_wind_direction
+        &clean_wind_speed_knots
+        &clean_gust_speed_knots
+        &clean_visibility_miles
+        &clean_temperature_c
+        &clean_dewpoint_c
+        &clean_pressure_hpa
+        &clean_relative_humidity
+
+        &load_icao_history
+
+        &validate_icao_history_set
+        &validate_icao_history_point
+        &validate_icao
+        &validate_date
+        &validate_wind_direction
+        &validate_wind_speed_knots
+        &validate_gust_speed_knots
+        &validate_visibility_miles
+        &validate_temperature_c
+        &validate_dewpoint_c
+        &validate_pressure_hpa
+        &validate_relative_humidity
     };
 our %EXPORT_TAGS    = (
-    all                     => [@EXPORT_OK],
-    validation  => [
+    all => [@EXPORT_OK],
+    conversion => [
         qw{
-            validate_icao_history_set
-            validate_icao_history_point
-            validate_icao
-            validate_date
-            validate_wind_direction
-            validate_wind_speed_knots
-            validate_gust_speed_knots
-            validate_visibility_miles
-            validate_temperature_c
-            validate_dewpoint_c
-            validate_pressure_hpa
-            validate_relative_humidity
+            &convert_from_fahrenheit_to_celsius
+            &convert_from_inches_of_mercury_to_hectopascals
+            &convert_from_miles_per_hour_to_knots
+        }
+    ],
+    cleaning => [
+        qw{
+            &clean_icao_history_set
+            &clean_icao_history_point
+            &clean_wind_direction
+            &clean_wind_speed_knots
+            &clean_gust_speed_knots
+            &clean_visibility_miles
+            &clean_temperature_c
+            &clean_dewpoint_c
+            &clean_pressure_hpa
+            &clean_relative_humidity
+        }
+    ],
+    validation => [
+        qw{
+            &validate_icao_history_set
+            &validate_icao_history_point
+            &validate_icao
+            &validate_date
+            &validate_wind_direction
+            &validate_wind_speed_knots
+            &validate_gust_speed_knots
+            &validate_visibility_miles
+            &validate_temperature_c
+            &validate_dewpoint_c
+            &validate_pressure_hpa
+            &validate_relative_humidity
         }
     ],
 );
@@ -52,6 +89,179 @@ use Regexp::Common;
 use Mac::Apps::Seasonality::Constants qw{ :database :data };
 use Mac::Apps::Seasonality::LoadICAOHistoryExceptions;
 
+
+sub convert_from_fahrenheit_to_celsius {
+    my ($fahrenheit) = @_;
+
+    return $fahrenheit if not defined $fahrenheit;
+    return $fahrenheit if q{} eq $fahrenheit;
+    return $fahrenheit if $SEASONALITY_INVALID_DATA == $fahrenheit;
+
+    return ($fahrenheit - 32.0) * 5.0 / 9.0;
+} # end convert_from_fahrenheit_to_celsius()
+
+sub convert_from_inches_of_mercury_to_hectopascals {
+    my ($inches) = @_;
+
+    return $inches if not defined $inches;
+    return $inches if q{} eq $inches;
+    return $inches if $SEASONALITY_INVALID_DATA == $inches;
+
+    return $inches * 33.863886667;
+} # end convert_from_inches_of_mercury_to_hectopascals()
+
+sub convert_from_miles_per_hour_to_knots {
+    my ($mph) = @_;
+
+    return $mph if not defined $mph;
+    return $mph if q{} eq $mph;
+    return $mph if $SEASONALITY_INVALID_DATA == $mph;
+
+    return $mph * 0.868976242;
+} # end convert_from_miles_per_hour_to_knots()
+
+sub clean_icao_history_set {
+    my $icao_history_ref = shift;
+    my $line_number = 1;
+    my @clean_messages;
+
+    foreach my $icao_history_point_ref (@{$icao_history_ref}) {
+        push
+            @clean_messages,
+            clean_icao_history_point($icao_history_point_ref, $line_number);
+
+        $line_number++;
+    } # end foreach
+
+    return @clean_messages;
+} # end clean_icao_history_set()
+
+sub clean_icao_history_point {
+    my ($icao_history_point_ref, $line_number) = @_;
+    my @clean_messages;
+
+    _check_basic_history_point_validity(
+        $icao_history_point_ref,
+        $line_number,
+        'clean_icao_history_point()'
+    );
+
+    push @clean_messages, clean_wind_direction(    $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_wind_speed_knots(  $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_gust_speed_knots(  $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_visibility_miles(  $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_temperature_c(     $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_dewpoint_c(        $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_pressure_hpa(      $icao_history_point_ref, $line_number);
+    push @clean_messages, clean_relative_humidity( $icao_history_point_ref, $line_number);
+
+    return @clean_messages;
+} # end clean_icao_history_point()
+
+sub clean_wind_direction {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_integer(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_WIND_DIRECTION,
+            $SEASONALITY_WIND_DIRECTION_MINIMUM,
+            $SEASONALITY_WIND_DIRECTION_MAXIMUM,
+        );
+} # end clean_wind_direction()
+
+sub clean_wind_speed_knots {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_integer(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_WIND_SPEED_KNOTS,
+            $SEASONALITY_WIND_SPEED_MINIMUM,
+            $SEASONALITY_WIND_SPEED_MAXIMUM,
+        );
+} # end clean_wind_speed_knots()
+
+sub clean_gust_speed_knots {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_integer(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_GUST_SPEED_KNOTS,
+            $SEASONALITY_WIND_SPEED_MINIMUM,
+            $SEASONALITY_WIND_SPEED_MAXIMUM,
+        );
+} # end clean_gust_speed_knots()
+
+sub clean_visibility_miles {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_floating_point(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_VISIBILITY_MILES,
+            $SEASONALITY_VISIBILITY_MINIMUM,
+            $SEASONALITY_VISIBILITY_MAXIMUM,
+        );
+} # end clean_visibility_miles()
+
+sub clean_temperature_c {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_floating_point(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_TEMPERATURE_C,
+            $SEASONALITY_TEMPERATURE_MINIMUM,
+            $SEASONALITY_TEMPERATURE_MAXIMUM,
+        );
+} # end clean_temperature_c()
+
+sub clean_dewpoint_c {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_floating_point(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_DEWPOINT_C,
+            $SEASONALITY_TEMPERATURE_MINIMUM,
+            $SEASONALITY_TEMPERATURE_MAXIMUM,
+        );
+} # end clean_dewpoint_c()
+
+sub clean_pressure_hpa {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_integer(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_PRESSURE_HPA,
+            $SEASONALITY_PRESSURE_MINIMUM,
+            $SEASONALITY_PRESSURE_MAXIMUM,
+        );
+} # end clean_pressure_hpa()
+
+sub clean_relative_humidity {
+    my ($icao_history_point_ref, $line_number) = @_;
+
+    return
+        _clean_integer(
+            $icao_history_point_ref,
+            $line_number,
+            $SEASONALITY_HISTORY_COLUMN_RELATIVE_HUMIDITY,
+            $SEASONALITY_RELATIVE_HUMIDITY_MINIMUM,
+            $SEASONALITY_RELATIVE_HUMIDITY_MAXIMUM,
+        );
+} # end clean_relative_humidity()
+
 sub load_icao_history {
     my ($database_connection, $icao_history_ref) = @_;
 
@@ -91,40 +301,11 @@ sub validate_icao_history_set {
 sub validate_icao_history_point {
     my ($icao_history_point_ref, $line_number) = @_;
 
-    if (! defined $icao_history_point_ref) {
-        ## no critic (RequireInterpolationOfMetachars)
-        Mac::Apps::Seasonality::InvalidDataSizeException->throw(
-            message =>
-                'INTERNAL ERROR: please report this to the maintainer--'
-                    . ' undefined $icao_history_point_ref passed to'
-                    . ' validate_icao_history_point().',
-            input_line_number => $line_number,
-            input_data_ref => $icao_history_point_ref,
-            expected_number_of_elements => $SEASONALITY_HISTORY_COLUMNS_COUNT,
-            actual_number_of_elements => 0,
-        );
-        ## use critic
-    } # end if
-
-    my $column_count = scalar @{$icao_history_point_ref};
-    my $incorrect_quantity_qualifier =
-        $SEASONALITY_HISTORY_COLUMNS_COUNT > $column_count
-            ? 'Insufficient'
-            : $SEASONALITY_HISTORY_COLUMNS_COUNT < $column_count
-                ? 'Excess'
-                : undef;
-    if ($incorrect_quantity_qualifier) {
-        Mac::Apps::Seasonality::InvalidDataSizeException->throw(
-            message =>
-                "$incorrect_quantity_qualifier data found on line $line_number;"
-                    . " expected $SEASONALITY_HISTORY_COLUMNS_COUNT columns,"
-                    . " but found $column_count columns.",
-            input_line_number => $line_number,
-            input_data_ref => $icao_history_point_ref,
-            expected_number_of_elements => $SEASONALITY_HISTORY_COLUMNS_COUNT,
-            actual_number_of_elements => $column_count,
-        );
-    } # end if
+    _check_basic_history_point_validity(
+        $icao_history_point_ref,
+        $line_number,
+        'clean_icao_history_point()'
+    );
 
     validate_icao(              $icao_history_point_ref, $line_number);
     validate_date(              $icao_history_point_ref, $line_number);
@@ -315,6 +496,199 @@ sub validate_relative_humidity {
     return;
 } # end validate_relative_humidity()
 
+sub _check_basic_history_point_validity {
+    # Don't want to mess with caller(), so explicit subroutine name is used.
+    my ($icao_history_point_ref, $line_number, $subroutine) = @_;
+
+    if (! defined $icao_history_point_ref) {
+        ## no critic (RequireInterpolationOfMetachars)
+        Mac::Apps::Seasonality::InvalidDataSizeException->throw(
+            message =>
+                'INTERNAL ERROR: please report this to the maintainer--'
+                    . ' undefined $icao_history_point_ref passed to'
+                    . " $subroutine.",
+            input_line_number => $line_number,
+            input_data_ref => $icao_history_point_ref,
+            expected_number_of_elements => $SEASONALITY_HISTORY_COLUMNS_COUNT,
+            actual_number_of_elements => 0,
+        );
+        ## use critic
+    } # end if
+
+    my $column_count = scalar @{$icao_history_point_ref};
+    my $incorrect_quantity_qualifier =
+        $SEASONALITY_HISTORY_COLUMNS_COUNT > $column_count
+            ? 'Insufficient'
+            : $SEASONALITY_HISTORY_COLUMNS_COUNT < $column_count
+                ? 'Excess'
+                : undef;
+    if ($incorrect_quantity_qualifier) {
+        Mac::Apps::Seasonality::InvalidDataSizeException->throw(
+            message =>
+                "$incorrect_quantity_qualifier data found on line $line_number;"
+                    . " expected $SEASONALITY_HISTORY_COLUMNS_COUNT columns,"
+                    . " but found $column_count columns.",
+            input_line_number => $line_number,
+            input_data_ref => $icao_history_point_ref,
+            expected_number_of_elements => $SEASONALITY_HISTORY_COLUMNS_COUNT,
+            actual_number_of_elements => $column_count,
+        );
+    } # end if
+
+    return;
+} # end _check_basic_history_point_validity()
+
+sub _clean_integer {
+    my (
+        $icao_history_point_ref,
+        $line_number,
+        $column_name,
+        $minimum_value,
+        $maximum_value
+    )
+        = @_;
+
+    my ($metric_value, $column_number, $defined_message) =
+        _get_value_and_column_number_and_clean_undefined(
+            $icao_history_point_ref,
+            $line_number,
+            $column_name,
+        );
+    my @clean_messages = $defined_message ? ( $defined_message ) : ( );
+
+    if ($metric_value !~ m/\A $RE{num}{int} \z/xms) {
+        my $real_column_number = $column_number - 1;
+
+        if ($metric_value =~ m/\A $RE{num}{real} \z/xms) {
+            my $int_value = int $metric_value + 0.5;
+            $icao_history_point_ref->[ $real_column_number ] = $int_value;
+
+            push
+                @clean_messages,
+                "Value given for $column_name ('$metric_value') on line"
+                    . " $line_number, column number $column_number, was"
+                    . " rounded to $int_value.";
+        } else {
+            $icao_history_point_ref->[ $real_column_number ] = $SEASONALITY_INVALID_DATA;
+
+            push
+                @clean_messages,
+                "Value given for $column_name ('$metric_value') on line"
+                    . " $line_number, column number $column_number, does not"
+                    . ' look like an integer. Will be treated as missing.';
+        };
+    } # end if
+
+    push
+        @clean_messages,
+        _clean_number_range(
+            $icao_history_point_ref,
+            $line_number,
+            $column_name,
+            $column_number,
+            $minimum_value,
+            $maximum_value
+        );
+
+    return @clean_messages;
+} # end _clean_integer()
+
+sub _clean_floating_point {
+    my (
+        $icao_history_point_ref,
+        $line_number,
+        $column_name,
+        $minimum_value,
+        $maximum_value
+    )
+        = @_;
+
+    my ($metric_value, $column_number, $defined_message) =
+        _get_value_and_column_number_and_clean_undefined(
+            $icao_history_point_ref,
+            $line_number,
+            $column_name,
+        );
+    my @clean_messages = $defined_message ? ( $defined_message ) : ( );
+
+    if ($metric_value !~ m/\A $RE{num}{real} \z/xms) {
+        $icao_history_point_ref->[ $column_number - 1 ] = $SEASONALITY_INVALID_DATA;
+
+        push
+            @clean_messages,
+            "Value given for $column_name ('$metric_value') on line"
+                . " $line_number, column number $column_number, does not"
+                . ' look like a number. Will be treated as missing.';
+    } # end if
+
+    push
+        @clean_messages,
+        _clean_number_range(
+            $icao_history_point_ref,
+            $line_number,
+            $column_name,
+            $column_number,
+            $minimum_value,
+            $maximum_value
+        );
+
+    return @clean_messages;
+} # end _clean_floating_point()
+
+sub _get_value_and_column_number_and_clean_undefined {
+    my ($icao_history_point_ref, $line_number, $column_name) = @_;
+
+    my $real_column_number =
+        $SEASONALITY_HISTORY_COLUMN_NUMBERS_BY_COLUMN_NAME_REF->{$column_name};
+
+    my $metric_value = $icao_history_point_ref->[ $real_column_number ];
+
+    my $column_number = $real_column_number + 1;
+
+    my $message;
+    if (not defined $metric_value or $metric_value eq q{}) {
+        $metric_value = $SEASONALITY_INVALID_DATA;
+        $icao_history_point_ref->[ $real_column_number ] = $metric_value;
+
+        $message =
+            "No value given for $column_name on line $line_number, column"
+                . " number $column_number.";
+    } # end if
+
+    return ($metric_value, $column_number, $message);
+} # end _get_value_and_column_number_and_clean_undefined()
+
+sub _clean_number_range {
+    my (
+        $icao_history_point_ref,
+        $line_number,
+        $column_name,
+        $column_number,
+        $minimum_value,
+        $maximum_value
+    )
+        = @_;
+
+    my $real_column_number = $column_number - 1;
+    my $metric_value = $icao_history_point_ref->[$real_column_number];
+
+    if ($metric_value == $SEASONALITY_INVALID_DATA) {
+        return;
+    } # end if
+
+    if ($metric_value < $minimum_value or $metric_value > $maximum_value) {
+        $icao_history_point_ref->[$real_column_number] = $SEASONALITY_INVALID_DATA;
+
+        return
+            "Value given for $column_name ('$metric_value') on line"
+                . " $line_number, column number $column_number, was not"
+                . " within the range $minimum_value to $maximum_value."
+                . ' Will be treated as a missing value.'
+    } # end if
+
+    return;
+} # end _clean_number_range()
+
 sub _validate_integer {
     my (
         $icao_history_point_ref,
@@ -381,7 +755,7 @@ sub _validate_floating_point {
             message =>
                 "Value given for $column_name ('$metric_value') on line"
                     . " $line_number, column number $column_number, does not"
-                    . ' look like a floating point number.',
+                    . ' look like a number.',
             input_line_number => $line_number,
             input_data_ref => $icao_history_point_ref,
             column_name => $column_name,
@@ -562,22 +936,30 @@ __END__
 
 =head1 NAME
 
-Mac::Apps::Seasonality::LoadICAOHistory -- load data into an SQLite2 database
+Mac::Apps::Seasonality::LoadICAOHistory -- Load data into an SQLite2 database
 with the Seasonality weather.db schema.
 
 
 =head1 VERSION
 
-This document describes Mac::Apps::Seasonality::LoadICAOHistory version 0.0.4.
+This document describes Mac::Apps::Seasonality::LoadICAOHistory version 0.0.5.
 
 
 =head1 SYNOPSIS
 
     use English qw{ -no_match_vars };
     use DBI;
-    use Mac::Apps::Seasonality::LoadICAOHistory qw{ load_icao_history };
+    use Mac::Apps::Seasonality::LoadICAOHistory qw{
+        :conversion
+        &clean_icao_history_set
+        &load_icao_history
+    };
     use Mac::Apps::Seasonality::Exceptions;
 
+    my $celsius = convert_from_fahrenheit_to_celsius( 32.0 );
+    my $hectopascals = convert_from_inches_of_mercury_to_hectopascals( 31.32);
+    my $knots = convert_from_miles_per_hour_to_knots( 5.5 );
+
     my $data =
         [
             [
@@ -629,6 +1011,8 @@ This document describes Mac::Apps::Seasonality::LoadICAOHistory version 0.0.4.
             }
         );
 
+    clean_icao_history_set($data);
+
     eval { load_icao_history($database_connection, $data) };
 
     my $exception
@@ -642,18 +1026,105 @@ This document describes Mac::Apps::Seasonality::LoadICAOHistory version 0.0.4.
 =head1 DESCRIPTION
 
 Seasonality L<http://gauchosoft.com/Software/Seasonality/> is a weather
-tracking and display application for Mac OS X.  This module provides a means of
-getting data into Seasonality that it cannot retrieve on its own.
+tracking and display application for Mac OS X.  This module provides a means
+of getting data into Seasonality that it cannot retrieve on its own.
 
 
 =head1 INTERFACE
 
+Nothing is exported by default, but you can import everything using the
+C<:all> tag.
+
+
+=head2 Conversion
+
+The following can be imported using the C<:conversion> tag.
+
+=over
+
+=item C<convert_from_fahrenheit_to_celsius($fahrenheit)>
+
+=item C<convert_from_inches_of_mercury_to_hectopascals($inches)>
+
+=item C<convert_from_miles_per_hour_to_knots($mph)>
+
+These do the obvious conversions, but return the original value if it is
+C<undef> or the
+L<Mac::Apps::Seasonality::Constants/"$SEASONALITY_INVALID_DATA"> value.
+
+=back
+
+
+=head2 Input data cleanup
+
+The following can be imported using the C<:cleaning> tag.
+
+=over
+
+=item C<clean_icao_history_set($icao_history_ref)>
+
+Takes a reference to an array of references to arrays containing values
+representing a single data point. The values in the second level arrays are
+expected to be in the icao_history table's schema column order. In other
+words, the parameter is a table that matches the icao_history database table's
+layout.
+
+Any invalid data in the set is marked as missing via the
+L<Mac::Apps::Seasonality::Constants/"$SEASONALITY_INVALID_DATA"> value.
+
+Returns a list of messages about the data that was affected.
+
+=item C<clean_icao_history_point($icao_history_point_ref, $line_number)>
+
+Takes a reference to an array of values representing a single data point and
+the original line number this data was found on in the input source.  The
+values are expected to be in the icao_history table's schema column order.
+
+Any invalid data in the point is marked as missing via the
+L<Mac::Apps::Seasonality::Constants/"$SEASONALITY_INVALID_DATA"> value.
+
+Returns a list of messages about the data that was affected.
+
+=back
+
+
+=head2 Individual column cleanup
+
+The following can be imported using the C<:cleaning> tag.
+
+=over
+
+=item C<clean_wind_direction(      $icao_history_point_ref, $line_number)>
+
+=item C<clean_wind_speed_knots(    $icao_history_point_ref, $line_number)>
+
+=item C<clean_gust_speed_knots(    $icao_history_point_ref, $line_number)>
+
+=item C<clean_visibility_miles(    $icao_history_point_ref, $line_number)>
+
+=item C<clean_temperature_c(       $icao_history_point_ref, $line_number)>
+
+=item C<clean_dewpoint_c(          $icao_history_point_ref, $line_number)>
+
+=item C<clean_pressure_hpa(        $icao_history_point_ref, $line_number)>
+
+=item C<clean_relative_humidity(   $icao_history_point_ref, $line_number)>
+
+Each of these takes a reference to an array of values representing a single
+data point and the original line number this data was found on in the input
+source. They pick out the datum that they are concerned about from the array
+and attempt to fix any problems they find.
+
+A list of messages about the modifications made is returned.
+
+=back
+
 
 =head2 Data loading.
 
 =over
 
-=item load_icao_history($database_connection, $icao_history_ref)
+=item C<load_icao_history($database_connection, $icao_history_ref)>
 
 Takes a reference to a DBI handle and to a reference to a set of ICAO metrics
 and loads the data into the database.
@@ -662,9 +1133,9 @@ C<$database_connection> must be an open handle to an SQLite2 database with
 Seasonality's schema.  This handle must have the RaiseError option set on it;
 this module does no error checking of database actions on its own.
 
-C<$icao_history_ref> must be a reference to an array of ICAO data points, where
-each data point is represented as a reference to an array of values in the
-following order:
+C<$icao_history_ref> must be a reference to an array of ICAO data points,
+where each data point is represented as a reference to an array of values in
+the following order:
 
 =over
 
@@ -690,9 +1161,9 @@ following order:
 
 =back
 
-=for commented out until individual validations are described.
-For limitations on these values, see the descriptions of the validation methods
-below.
+=for TODO commented out until individual validations are described.
+For limitations on these values, see the descriptions of the validation
+methods below.
 
 If the attempt to load data is successful, no useful data is returned.  All
 failures result in exceptions.
@@ -702,14 +1173,17 @@ failures result in exceptions.
 
 =head2 Input data validation
 
+The following can be imported using the C<:validation> tag.
+
 =over
 
-=item validate_icao_history_set($icao_history_ref)
+=item C<validate_icao_history_set($icao_history_ref)>
 
 Takes a reference to an array of references to arrays containing values
 representing a single data point. The values in the second level arrays are
-expected to be in the icao_history table's schema column order. In other words,
-the parameter is a table that matches the icao_history database table's layout.
+expected to be in the icao_history table's schema column order. In other
+words, the parameter is a table that matches the icao_history database table's
+layout.
 
 If the data is valid, no useful value is returned.
 
@@ -717,7 +1191,7 @@ If the data is invalid, an instance of
 L<Mac::Apps::Seasonality::InvalidDatumException> describing the problem is
 thrown.
 
-=item validate_icao_history_point($icao_history_point_ref, $line_number)
+=item C<validate_icao_history_point($icao_history_point_ref, $line_number)>
 
 Takes a reference to an array of values representing a single data point and
 the original line number this data was found on in the input source.  The
@@ -734,18 +1208,29 @@ thrown.
 
 =head2 Individual column validation
 
+The following can be imported using the C<:validation> tag.
+
 =over
 
-=item validate_icao(                $icao_history_point_ref, $line_number)
-=item validate_date(                $icao_history_point_ref, $line_number)
-=item validate_wind_direction(      $icao_history_point_ref, $line_number)
-=item validate_wind_speed_knots(    $icao_history_point_ref, $line_number)
-=item validate_gust_speed_knots(    $icao_history_point_ref, $line_number)
-=item validate_visibility_miles(    $icao_history_point_ref, $line_number)
-=item validate_temperature_c(       $icao_history_point_ref, $line_number)
-=item validate_dewpoint_c(          $icao_history_point_ref, $line_number)
-=item validate_pressure_hpa(        $icao_history_point_ref, $line_number)
-=item validate_relative_humidity(   $icao_history_point_ref, $line_number)
+=item C<validate_icao(                $icao_history_point_ref, $line_number)>
+
+=item C<validate_date(                $icao_history_point_ref, $line_number)>
+
+=item C<validate_wind_direction(      $icao_history_point_ref, $line_number)>
+
+=item C<validate_wind_speed_knots(    $icao_history_point_ref, $line_number)>
+
+=item C<validate_gust_speed_knots(    $icao_history_point_ref, $line_number)>
+
+=item C<validate_visibility_miles(    $icao_history_point_ref, $line_number)>
+
+=item C<validate_temperature_c(       $icao_history_point_ref, $line_number)>
+
+=item C<validate_dewpoint_c(          $icao_history_point_ref, $line_number)>
+
+=item C<validate_pressure_hpa(        $icao_history_point_ref, $line_number)>
+
+=item C<validate_relative_humidity(   $icao_history_point_ref, $line_number)>
 
 Each of these takes a reference to an array of values representing a single
 data point and the original line number this data was found on in the input
@@ -763,31 +1248,13 @@ thrown.
 
 =head1 DIAGNOSTICS
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
+TODO
 
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-This module assumes that it is running against a database in the format used by
-Seasonality versions 1.3 and 1.4.
+This module assumes that it is running against a database in the format used
+by Seasonality versions 1.3 and 1.4.
 
 
 =head1 DEPENDENCIES
@@ -812,8 +1279,7 @@ than version 1.3.
 =item · Dates are only checked that they consist of twelve digits and are not
 yet checked to see whether they are valid in the Gregorian calendar.
 
-=item · The boilerplate for the DIAGNOSTICS section above has not been
-replaced.
+=item · The DIAGNOSTICS section above has not been filled in.
 
 =back
 
@@ -853,12 +1319,12 @@ SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE LIABLE TO YOU FOR DAMAGES,
 INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING
 OUT OF THE USE OR INABILITY TO USE THE SOFTWARE (INCLUDING BUT NOT LIMITED TO
 LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR
-THIRD PARTIES OR A FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE),
-EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
+THIRD PARTIES OR A FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER
+SOFTWARE), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
+POSSIBILITY OF SUCH DAMAGES.
 
 =cut
 
 # setup vim: set filetype=perl tabstop=4 softtabstop=4 expandtab :
-# setup vim: set shiftwidth=4 shiftround textwidth=0 nowrap autoindent :
+# setup vim: set shiftwidth=4 shiftround textwidth=78 nowrap autoindent :
 # setup vim: set foldmethod=indent foldlevel=0 :
